import "ecere"
import "ede"

class FileSystemBoxTestWindow : Window
{
   text = "FileSystemBox Test Window";
   background = activeBorder;
   borderStyle = sizable;
   hasMaximize = true;
   hasMinimize = true;
   hasClose = true;
   size = { 840, 480 };

   TabControl tabControl { this, background = activeBorder, anchor = { left = 4, top = 4, right = 4, bottom = 4 } };

   FileListTab fileListTab { tabControl };
   FolderListTab folderListTab { tabControl };
   FileTreeTab fileTreeTab { tabControl };
   FolderTreeTab folderTreeTab { tabControl };
   FileDetails fileDetails { tabControl };
   FilteredList filteredList { tabControl };
   FilteredTree filteredTree { tabControl };
   RootList rootList { tabControl };
   RootTree rootTree { tabControl };
}

FileSystemBoxTestWindow testWindow { };

class TestTab : Tab
{
   background = activeBorder;
}

class FileListTab : TestTab
{
   text = "FileList";

   FileSystemBox box
   {
      this;
      anchor = { left = 4, top = 4, right = 4, bottom = 4 };
   };
}

class FolderListTab : TestTab
{
   text = "FolderList";

   FileSystemBox box
   {
      this;
      foldersOnly = true;
      anchor = { left = 4, top = 4, right = 4, bottom = 4 };
   };
}

class FileTreeTab : TestTab
{
   text = "FileTree";

   FileSystemBox box
   {
      this;
      treeBranches = true;
      anchor = { left = 4, top = 4, right = 4, bottom = 4 };
   };
}

class FolderTreeTab : TestTab
{
   text = "FolderTree";

   FileSystemBox box
   {
      this;
      treeBranches = true;
      foldersOnly = true;
      anchor = { left = 4, top = 4, right = 4, bottom = 4 };
   };
}

class FileDetails : TestTab
{
   text = "FileDetails";

   FileSystemBox box
   {
      this;
      details = true; // TODO: figure out why commented out (see FileSystemBox) code crashes the form designer
      anchor = { left = 4, top = 4, right = 4, bottom = 4 };
   };
}

class FilteredList : TestTab
{
   text = "FilteredList";

   FileSystemBox box
   {
      this;
      extensions = "epj, ec";
      anchor = { left = 4, top = 4, right = 4, bottom = 4 };
   };
}

class FilteredTree : TestTab
{
   text = "FilteredTree";

   FileSystemBox box
   {
      this;
      anchor = { left = 4, top = 4, right = 4, bottom = 4 };

      extensions = "txt, text, nfo, info";
      treeBranches = true;
   };
}

class RootList : TestTab
{
   text = "RootList";

   FileSystemBox box
   {
      this;
      path = "/";
      anchor = { left = 4, top = 4, right = 4, bottom = 4 };
   };
}

class RootTree : TestTab
{
   text = "RootTree";

   FileSystemBox box
   {
      this;
      path = "/";
      anchor = { left = 4, top = 4, right = 4, bottom = 4 };

      treeBranches = true;
   };
}

class FileSystemBoxTestApp : GuiApplication
{
}
